<figure markdown>
![Logo](https://cdn2.iconfinder.com/data/icons/social-media-applications/64/social_media_applications_28-yelp-512.png){ width="100" }
</figure>

# ezapi-yelp

A Python wrapper for [Yelp Fusion API](https://docs.developer.yelp.com/docs/fusion-intro)
